.. tutorials


Tutorials
=========

.. toctree::
    :maxdepth: 1
    :caption: Sample Data Sets

    notebooks/1_sample_data.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Data Input/Output

    notebooks/2_data_input_output.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Basic Mapping

    notebooks/3_basic_mapping.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Spatial Weights

    notebooks/4_spatial_weights.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Basic Ordinary Least Squares Regression (OLS)

    notebooks/5_OLS.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Two Stage Least Squares Regression (2SLS)

    notebooks/6_TWOSLS.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Spatial Model Specifications

    notebooks/7_spatial_models.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Spatial Multipliers

    notebooks/8_spatial_multipliers.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Specification Tests

    notebooks/9_specification_tests.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Specification Tests - Properties

    notebooks/10_specification_tests_properties.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Distance Decay

    notebooks/11_distance_decay.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Estimating SLX Models

    notebooks/12_estimating_slx.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Maximum Likelihood Estimation - Spatial Lag Model

    notebooks/13_ML_estimation_spatial_lag.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Instrumental Variables Estimation - Spatial Lag Model

    notebooks/14_IV_estimation_spatial_lag.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Maximum Likelihood Estimation - Spatial Error Model

    notebooks/15_ML_estimation_spatial_error.ipynb

.. toctree::
    :maxdepth: 1
    :caption: GMM Estimation - Spatial Error Model

    notebooks/16_GMM_estimation_spatial_error.ipynb

.. toctree::
    :maxdepth: 1
    :caption: GMM Estimation - Higher Order Models

    notebooks/17_GMM_higher_order.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Spatial Panel Models with Fixed Effects
    
    notebooks/Panel_FE_example.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Skater_reg: Endogenous Spatial Regimes
    
    notebooks/skater_reg.ipynb
